summaryrefslogtreecommitdiffstats
path: root/source/autogen.sh
diff options
context:
space:
mode:
Diffstat (limited to 'source/autogen.sh')
-rwxr-xr-xsource/autogen.sh16
1 files changed, 8 insertions, 8 deletions
diff --git a/source/autogen.sh b/source/autogen.sh
index 6042b82cdce..922cad8e613 100755
--- a/source/autogen.sh
+++ b/source/autogen.sh
@@ -1,11 +1,11 @@
#!/bin/sh
# Run this script to build samba from CVS.
## insert all possible names (only works with
## autoconf 2.x
-TESTAUTOHEADER="autoheader autoheader-2.53"
-TESTAUTOCONF="autoconf autoconf-2.53"
+TESTAUTOHEADER="autoheader autoheader-2.53 autoheader2.50"
+TESTAUTOCONF="autoconf autoconf-2.53 autoconf2.50"
AUTOHEADERFOUND="0"
AUTOCONFFOUND="0"
@@ -43,11 +43,14 @@ done
## do we have it?
##
if [ "$AUTOCONFFOUND" = "0" -o "$AUTOHEADERFOUND" = "0" ]; then
- echo "$0: need autoconf 2.53 or later to build samba from CVS" >&2
+ echo "$0: need autoconf 2.53 or later to build samba from SVN" >&2
exit 1
fi
+echo "$0: running script/mkversion.sh"
+./script/mkversion.sh || exit 1
+rm -rf autom4te*.cache
echo "$0: running $AUTOHEADER"
$AUTOHEADER || exit 1
@@ -55,10 +58,7 @@ $AUTOHEADER || exit 1
echo "$0: running $AUTOCONF"
$AUTOCONF || exit 1
-echo "$0: running script/mkversion.sh"
-./script/mkversion.sh || exit 1
-
-rm -rf autom4te.cache autom4te-2.53.cache
+rm -rf autom4te*.cache
echo "Now run ./configure and then make."
exit 0
@@ -1,11 +1,11 @@
#!/bin/sh
-# Run this script to build samba from CVS.
+# Run this script to build samba from SVN.
## insert all possible names (only works with
## autoconf 2.x